#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 numtype-dk
version:              0.5.0.3
visibility:           public
id:                   numtype-dk-0.5.0.3-8Y8uzPE3pvRJbRmzxZil8Z
key:                  numtype-dk-0.5.0.3-8Y8uzPE3pvRJbRmzxZil8Z
license:              BSD-3-Clause
copyright:            Bjorn Buckwalter 2012-2021
maintainer:           bjorn@buckwalter.se
author:               Bjorn Buckwalter
stability:            provisional
homepage:             https://github.com/bjornbm/numtype-dk
synopsis:
    Type-level integers, using TypeNats, Data
    Kinds, and Closed Type Families.

description:
    This package provides type level representations of the
    (positive and negative) integers and basic operations (addition,
    subtraction, multiplication, division, exponentiation) on these.
    The numtype-dk package differs from the numtype package in that
    the NumTypes are implemented using Data Kinds, TypeNats, and
    Closed Type Families rather than Functional Dependencies.
    Requires GHC 7.8 or later.

category:             Math
abi:                  750bfa99c095643d78a9536fe1aeb383
exposed:              True
exposed-modules:      Numeric.NumType.DK.Integers
hidden-modules:       Numeric.NumType.DK.Naturals
import-dirs:          /usr/lib/ghc-9.6.6/site-local/numtype-dk-0.5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/numtype-dk-0.5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/numtype-dk-0.5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numtype-dk
hs-libraries:         HSnumtype-dk-0.5.0.3-8Y8uzPE3pvRJbRmzxZil8Z
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-numtype-dk/html/numtype-dk.haddock
haddock-html:         /usr/share/doc/haskell-numtype-dk/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

